<?php

require_once WICKED_BASE . '/lib/Page/StandardPage.php';

/**
 * Wicked EditPage class.
 *
 * $Horde: wicked/lib/Page/EditPage.php,v 1.4 2004/12/01 16:28:08 eraserhd Exp $
 *
 * @author  Jason M. Felice <jfelice@cronosys.com>
 * @version $Revision: 1.4 $
 * @package Wicked
 */
class EditPage extends Page {

    /**
     * Display modes supported by this page.
     * @var array $supportedModes
     */
    var $supportedModes = array(
        WICKED_MODE_DISPLAY => true);

    /**
     * The page that we're displaying backlinks to.
     * @var string $_referrer
     */
    var $_referrer = null;

    function EditPage($referrer)
    {
        $this->_referrer = $referrer;
    }

    /** 
     * Retrieve this user's permissions for the referring page.
     *
     * @return integer  The permissions bitmask.
     */
    function getPermissions()
    {
        $page = &Page::getPage($this->referrer(), null, null, null, null);
        return $page->getPermissions();
    }

    /**
     * Render this page in Display mode.
     *
     * @return mixed                Returns true or PEAR_Error.
     */
    function display()
    {
        global $wicked;

        $page = &Page::getPage($this->referrer(), null, null, null, null);

        if (!$page->allows(WICKED_MODE_EDIT)) {
            $notification->push(sprintf(_("You don't have permission to edit '%s'."), $page->pageName()));
            $url = Horde::applicationUrl('display.php', true);
            $url = Util::addParameter($url, 'page', $page->pageName());
            header('Location: ' . $url);
            exit;
        }

        $page_text = Util::getFormData('page_text');
        if (is_null($page_text)) {
            $page_text = $page->getText();
        }

        require WICKED_TEMPLATES . '/edit/standard.inc';
        return true;
    }

    function pageName()
    {
        return _("EditPage");
    }

    function referrer()
    {
        return $this->_referrer;
    }

    function pageUrl($linkpage = 'display.php', $actionid = 'none')
    {
        $url = Horde::applicationUrl($linkpage);
        return Util::addParameter($url, array('page' => $this->pageName(),
                                              'referrer' => $this->referrer(),
                                              'actionID' => $actionid));
    }

    function handleAction()
    {
        global $wicked, $notification, $conf;

        $page = &Page::getPage($this->referrer(), null, null, null, null);

        if (!$page->allows(WICKED_MODE_EDIT)) {
            $notification->push(sprintf(_("You don't have permission to edit '%s'."), $page->pageName()));
        } else {
            $text = Util::getFormData('page_text');
            $changelog = Util::getFormData('changelog');
            if ($conf['wicked']['require_change_log'] && empty($changelog)) {
                $notification->push(_("You must enter a change description to save the page."), 'horde.error');
                return;
            }
            $minorchange = Util::getFormData('minor');
            if (trim($text) == trim($page->getText())) {
                $notification->push(_("No changes made"), 'horde.warning');
            } else {
                $result = $page->updateText($text, $changelog, $minorchange);
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(sprintf(_("Save Failed: %s"),
                                                $result->toString()),
                                        'horde.error');
                } else {
                    $notification->push(_("Page Saved"), 'horde.success');
                }
            }
        }

        // Show the newly saved page.
        $url = Horde::applicationUrl('display.php', true);
        $url = Util::addParameter($url, 'page', $page->pageName());
        header('Location: ' . $url);
        exit;
    }

}
